@@ -4,10 +4,8 @@ import json
 import click
 import sys
 
-from nomad import utils
-from nomad import parsing
-from nomad import normalizing
-from nomad import datamodel
+from nomad import utils, parsing, normalizing, datamodel
+
 import nomadcore
 
 from .cli import cli
@@ -22,15 +20,16 @@ def parse(
     Run the given parser on the downloaded calculation. If no parser is given,
     do parser matching and use the respective parser.
     '''
+    from nomad.parsing import parsers
     mainfile = os.path.basename(mainfile_path)
 
     if logger is None:
         logger = utils.get_logger(__name__)
     if parser_name is not None:
-        parser = parsing.parser_dict.get(parser_name)
+        parser = parsers.parser_dict.get(parser_name)
         assert parser is not None, 'the given parser must exist'
     else:
-        parser = parsing.match_parser(mainfile_path, strict=strict)
+        parser = parsers.match_parser(mainfile_path, strict=strict)
         if isinstance(parser, parsing.MatchingParser):
             parser_name = parser.name
         else:
@@ -44,6 +43,16 @@ def parse(
 
     parser_backend = parser.run(mainfile_path, logger=logger)
 
+    from nomad.metainfo import MSection
+    from nomad.parsing.legacy import Backend
+
+    if isinstance(parser_backend, MSection):
+        backend = Backend(parser._metainfo_env, parser.domain)
+        root_section = str(datamodel.domains[parser.domain]['root_section'])
+        setattr(backend.entry_archive, root_section, parser_backend)
+        backend.resource.add(parser_backend)
+        parser_backend = backend
+
     if not parser_backend.status[0] == 'ParseSuccess':
         logger.error('parsing was not successful', status=parser_backend.status)
 
