@@ -120,7 +120,7 @@ elastic = NomadConfig(
 )
 
 keycloak = NomadConfig(
-    server_url='https://repository.nomad-coe.eu/fairdi/keycloak/auth/',
+    server_url='https://nomad-lab.eu/fairdi/keycloak/auth/',
     realm_name='fairdi_nomad_test',
     username='admin',
     password='password',
@@ -250,7 +250,7 @@ normalize = NomadConfig(
 client = NomadConfig(
     user='leonard.hofstadter@nomad-fairdi.tests.de',
     password='password',
-    url='http://repository.nomad-coe.eu/app/api'
+    url='http://nomad-lab.eu/prod/rae/api'
 )
 
 datacite = NomadConfig(
@@ -262,14 +262,14 @@ datacite = NomadConfig(
 )
 
 meta = NomadConfig(
-    version='0.8.1',
+    version='0.8.3',
     commit=gitinfo.commit,
     release='devel',
     default_domain='dft',
     service='unknown nomad service',
     name='novel materials discovery (NOMAD)',
     description='A FAIR data sharing platform for materials science data',
-    homepage='https://repository.nomad-coe.eu/v0.8',
+    homepage='https://https://nomad-lab.eu',
     source_url='https://gitlab.mpcdf.mpg.de/nomad-lab/nomad-FAIR',
     maintainer_email='markus.scheidgen@physik.hu-berlin.de'
 )
@@ -393,7 +393,7 @@ def load_config(config_file: str = os.environ.get('NOMAD_CONFIG', 'nomad.yaml'))
                                     'config key %s value %s has wrong type: %s' % (key, str(value), str(e)))
                         else:
                             config[key] = value
-                            logger.info('override config key %s with value %s' % (key, str(value)))
+                            logger.debug('override config key %s with value %s' % (key, str(value)))
                 else:
                     logger.error('config key %s does not exist' % key)
 
