@@ -13,12 +13,31 @@
 # limitations under the License.
 
 '''
+Introduction
+------------
+
+This is about the *datamodel* that is used to represent NOMAD entries in our databases and
+search engines. The respective data, also known as (repository) metadata is also part of
+the NOMAD Archive and the datamodel is also defined based on the NOMAD Metainfo
+(section *metadata*). It covers all information that users can search for and that can
+be easily rendered on the GUI. The information is readily available through the
+**repo** API.
+
+.. image:: assets/data.png
+
+See also the `datamodel section in the introduction <introduction.html#data-model>`_.
+
 This module contains classes that allow to represent the core
 nomad data entities (entries/calculations, users, datasets) on a high level of abstraction
 independent from their representation in the different modules
 :py:mod:`nomad.processing`, :py:mod:`nomad.parsing`, :py:mod:`nomad.search`, :py:mod:`nomad.app`.
 
-It is not about representing every detail, but those parts that are directly involved in
+Datamodel entities
+------------------
+
+The entities in the datamodel are defined as NOMAD Metainfo sections. They are treated
+similarily to all Archive data. The entry/calculation datamodel data is created during
+processing. It is not about representing every detail, but those parts that are directly involved in
 api, processing, mirroring, or other 'infrastructure' operations.
 
 The class :class:`User` is used to represent users and their attributes.
@@ -41,7 +60,12 @@ The class :class:`EntryMetadata` is used to represent all metadata about an entr
 .. autoclass:: nomad.datamodel.EntryMetadata
     :members:
 
-In addition there are domain specific metadata classes:
+Domains
+------------------
+
+The datamodel supports different *domains*. This means that most domain metadata of an
+entry/calculation is stored in domain-specific sub sections of the :class:`EntryMetadata`
+section. We currently have the following domain specific metadata classes/sections:
 
 .. autoclass:: nomad.datamodel.dft.DFTMetadata
     :members:
@@ -51,6 +75,9 @@ In addition there are domain specific metadata classes:
 
 .. autoclass:: nomad.datamodel.OptimadeEntry
     :members:
+
+.. automodule:: nomad.datamodel.encyclopedia
+    :members:
 '''
 
 from .dft import DFTMetadata
