@@ -38,13 +38,15 @@ from structlog.processors import StackInfoRenderer, format_exc_info, TimeStamper
 from nomad import utils, config, infrastructure, search, datamodel
 from nomad.files import PathObject, UploadFiles, ExtractError, ArchiveBasedStagingUploadFiles, PublicUploadFiles, StagingUploadFiles
 from nomad.processing.base import Proc, process, task, PENDING, SUCCESS, FAILURE
-from nomad.parsing import parser_dict, match_parser, Backend
+from nomad.parsing import Backend
+from nomad.parsing.parsers import parser_dict, match_parser
 from nomad.normalizing import normalizers
 from nomad.datamodel import EntryArchive
 from nomad.archive import query_archive
 from nomad.datamodel.encyclopedia import (
     EncyclopediaMetadata,
 )
+from nomad.metainfo import MSection
 import phonopyparser
 
 
@@ -383,6 +385,14 @@ class Calc(Proc):
             try:
                 self._parser_backend = parser.run(
                     self.upload_files.raw_file_object(self.mainfile).os_path, logger=logger)
+
+                if isinstance(self._parser_backend, MSection):
+                    backend = Backend(parser._metainfo_env, parser.domain)
+                    root_section = datamodel.domains[parser.domain]['root_section']
+                    setattr(backend.entry_archive, root_section, self._parser_backend)
+                    backend.resource.add(self._parser_backend)
+                    self._parser_backend = backend
+
             except Exception as e:
                 self.fail('parser failed with exception', exc_info=e, error=str(e), **context)
                 return
@@ -447,7 +457,10 @@ class Calc(Proc):
             self._entry_metadata.dft.update_group_hash()
         except Exception as e:
             logger.error("Could not retrieve method information for phonon calculation.", exception=e)
+            if self._entry_metadata.encyclopedia is None:
+                self._entry_metadata.encyclopedia = EncyclopediaMetadata()
             self._entry_metadata.encyclopedia.status = EncyclopediaMetadata.status.type.failure
+
         finally:
             # persist the calc metadata
             with utils.timer(logger, 'saved calc metadata', step='metadata'):
@@ -1027,8 +1040,8 @@ class Upload(Proc):
             modified_upload = self._get_collection().find_one_and_update(
                 {'_id': self.upload_id, 'joined': {'$ne': True}},
                 {'$set': {'joined': True}})
-            if modified_upload is not None:
-                self.get_logger().debug('join')
+            if modified_upload is None or modified_upload['joined'] is False:
+                self.get_logger().info('join')
 
                 # Before cleaning up, run an additional normalizer on phonon
                 # calculations. TODO: This should be replaced by a more
